==> lms-1.3.0+libs.tar.gz: lms/lib/fortunes.php <==
<?php

/*
 * LMS version 1.3.0 Apophis
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: fortunes.php,v 1.5 2004/02/18 12:49:23 lukasz Exp $
 */

$fortunes[] = "Moesz si pokaleczy wymachujc siekier?";
$fortunes[] = "Komputer nie podczony do rda zasilania zdecydowanie odmwi dziaania.";
$fortunes[] = "Dowiadczenie to co, co zdobywasz tu po chwili w ktrej go potrzebowae.";
$fortunes[] = "Najlepsz metod do zainspirowania odkrywczych myli, jest zaklejenie koperty.";
$fortunes[] = "Wszystko zabiera znacznie wicej czasu, ni by si wydawao.";
$fortunes[] = "Zawsze kiedy masz wanie co zrobi, okazuje si, e najpierw musisz zrobi co innego.";
$fortunes[] = "Kade rozwizanie rodzi nowe problemy.";
$fortunes[] = "Gupcy s tak pomysowi, e niemoliwe jest stworzenie czego, z czym kady gupi sobie poradzi.";
$fortunes[] = "Matka Natura jest suk.";
$fortunes[] = "Rzeczy ulegaj zniszczeniu, wprost proporcjonalnie do swej wartoci.";
$fortunes[] = "Wszystkie sprawy szlag trafia jednoczenie.";
$fortunes[] = "Jeeli wydaje ci si, e ju gorzej by nie moe - na pewno bdzie.";
$fortunes[] = "Zawsze, kiedy wydaje ci si, e bdzie dobrze - kompletnie si mylisz.";
$fortunes[] = "Zawsze, kiedy wydaje ci si, e bdzie le te si mylisz - bdzie jeszcze gorzej.";
$fortunes[] = "Bardzo duo mona zauway, gdy si patrzy.";
$fortunes[] = "Jeli co si wydarza to znaczy, e jest to moliwe. Zatem w walce midzy tob, a wiatem, sta po stronie wiata.";
$fortunes[] = "W poszukiwaniu rozwizania problemu, najbardziej pomocna jest znajomo odpowiedzi.";
$fortunes[] = "Kady przedmiot niezalenie od pooenia, moe w dowolnej chwili zadziaa w zupenie nieoczekiwany sposb z przyczyn, ktre s albo cakowicie niejasne, albo zupenie tajemnicze.";
$fortunes[] = "Wymiary bd zawsze podane w najmniej uytecznych jednostkach.";
$fortunes[] = "Kady przewd przycity na dugo, okae si za krtki.";
$fortunes[] = "Stopie gupoty twojego postpowania, jest wprost proporcjonalny do liczby przygldajcych ci si osb.";
$fortunes[] = "Prawdopodobiestwo wyczerpania si baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$fortunes[] = "Ciar upuszczonej czci jest wprost proporcjonalny do ceny obszaru uderzonego.";
$fortunes[] = "To czego szukasz, znajdziesz w ostatnim spord moliwych miejsc.";
$fortunes[] = "Wniosek to punkt, w ktrym nie masz ju siy dalej myle.";
$fortunes[] = "To co moe si nie uda, nie uda si na pewno.";
$fortunes[] = "Cztery zjawiska blokuj postp ludzkoci - ignorancja, gupota, komitety normalizacyjne, oraz ludzie sprzedajcy komputery.";
$fortunes[] = "Istniej trzy rodzaje kamstw - kamstwa odruchowe, powszechne oraz testy komputerowe.";
$fortunes[] = "Czowiek pracujcy z komputerem, nie postpuje zgodnie z wymaganiami komputera.";
$fortunes[] = "Systemy odporne na idiotw, obsugiwane s wanie przez nich.";
$fortunes[] = "Rozoenie dowolnego urzdzenia na czci jest proste, ponowne jego zoenie, tak eby dziaao, jest niemoliwe.";
$fortunes[] = "Kady skomplikowany monta wymaga trzech rk.";
$fortunes[] = "Kady prosty monta wymaga czterech rk.";
$fortunes[] = "Sprawy pozostawione same sobie, zmieniaj si ze zych na jeszcze gorsze.";
$fortunes[] = "Wszystkie komputery PC s kompatybilne, ale niektre s kompatybilniejsze od innych. Twj jest zawsze mniej kompatybilny.";
$fortunes[] = "Pust dyskietk moesz przeszukiwa dugo i bezskutecznie. Dugo i bezskutecznie moesz przeszukiwa take pen dyskietk. Wniosek - kad dyskietk moesz przeszukiwa dugo i bezskutecznie.";
$fortunes[] = "Komputer suy do tego aby uatwi ci prac, ktrej bez niego w ogle by nie mia.";
$fortunes[] = "Dla komputera nie ma rzeczy niemoliwych z wyjtkiem tych, ktrych od niego wymagamy.";
$fortunes[] = "W wiecie komputerw adna awaria si nie koczy, poniewa przechodzi zawsze w nastpn.";
$fortunes[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitonie zaatakowa.";
$fortunes[] = "W pracy z komputerem, opieranie si na jakichkolwiek zasadach jest bdem.";
$fortunes[] = "Drobne awarie nie isniej, jeeli miaa jednak miejsce drobna awaria, oznacza to, e nie poznae jeszcze jej rzeczywistych rozmiarw.";
$fortunes[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej ci zawiedzie. Kady inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, dziaa bez zakce.";
$fortunes[] = "Masz zawsze o jeden wirus wicej ni sdzisz.";
$fortunes[] = "Program kalkulacyjny, ktry daje waciwy i przyjazny wynik - kamie.";
$fortunes[] = "Wyjtki s liczniejsze od regu. Od wszystkich uznanych wyjtkw istniej wyjtki.";
$fortunes[] = "Klientowi nigdy nie przyjdzie na myl ile kosztuje projekt, tylko ile mona na tym projekcie zaoszczdzi. Jeeli udao ci si wprowadzi w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. aden klient nie wie czego waciwie chce. Kady klient wie dokadnie czego nie chce. aden klient nie chce tego co masz ju gotowe. Nie wie take co chciaby mie zamiast tego. Klient, ktry najmniej paci, marudzi najwicej. Klient da najwikszych zmian dokadnie wtedy, kiedy produkt jest ju gotowy.";
$fortunes[] = "Na polecenie \"napisz tak lub nie\" uytkownik wpisuje \"tak lub nie\". Na polecenie \"wcinij Enter\" uytkownik wpisuje \"Enter\". Na polecenie \"nacinij dowolny klawisz\", uytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programw cakowicie idiotoodpornych.";
$fortunes[] = "W zespole programistw kady ma genialny plan rozwizania problemu. Wszystkie plany si wzajemnie wykluczaj i aden nie prowadzi do poprawnego rozwizania. Liczba osb w zespole programistycznym ma tendencje wzrastajce, niezalenie od iloci pracy.";
$fortunes[] = "01:04 < [hunter]> robi dokumentacje ?
01:04 < [hunter]> :)
01:04 <@Warden> dokumentacj? rb
01:04 <@Warden> ;)
01:04 <@Warden> Baseciq:: jest chtny!
01:04 <@Warden> ;)
01:05 <@Baseciq> zwicie go!!!!!!!!!
01:05 <@Baseciq> szybko!!!
01:05 <@Baseciq> bo ucieknie!!!
01:06 <@agaran> :>
01:08 <@agaran> :>>> Hunterq uwazaj";

$fortunes[] = "19:16.31| <@Baseciq> SELECT users.id, lastname, SUM((type * -2 + 7) * value) FROM users LEFT OUTER JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE status=3 AND deleted=0 GROUP BY users.id;
19:17.00| <@Lexx__> Wy z tymi zapytaniami jobla dostajcie ;P";		     

$fortunes[] = "Lexx (0:16)
GPL nie przewiduje zdaje sie braku odpowiedzialnosci za smierc przez kod ;]";

mt_srand ((double) microtime()* 100000000);
$layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];

?>

==> lms-1.3.2+libs.tar.gz: lms/lib/fortunes.php <==
<?php

/*
 * LMS version 1.3-cvs
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: fortunes.php,v 1.8 2004/04/02 10:06:43 alec Exp $
 */

$fortunes[] = "Moesz si pokaleczy wymachujc siekier?";
$fortunes[] = "Komputer nie podczony do rda zasilania zdecydowanie odmwi dziaania.";
$fortunes[] = "Dowiadczenie to co, co zdobywasz tu po chwili w ktrej go potrzebowae.";
$fortunes[] = "Najlepsz metod do zainspirowania odkrywczych myli, jest zaklejenie koperty.";
$fortunes[] = "Wszystko zabiera znacznie wicej czasu, ni by si wydawao.";
$fortunes[] = "Zawsze kiedy masz wanie co zrobi, okazuje si, e najpierw musisz zrobi co innego.";
$fortunes[] = "Kade rozwizanie rodzi nowe problemy.";
$fortunes[] = "Gupcy s tak pomysowi, e niemoliwe jest stworzenie czego, z czym kady gupi sobie poradzi.";
$fortunes[] = "Matka Natura jest suk.";
$fortunes[] = "Rzeczy ulegaj zniszczeniu, wprost proporcjonalnie do swej wartoci.";
$fortunes[] = "Wszystkie sprawy szlag trafia jednoczenie.";
$fortunes[] = "Jeeli wydaje ci si, e ju gorzej by nie moe - na pewno bdzie.";
$fortunes[] = "Zawsze, kiedy wydaje ci si, e bdzie dobrze - kompletnie si mylisz.";
$fortunes[] = "Zawsze, kiedy wydaje ci si, e bdzie le te si mylisz - bdzie jeszcze gorzej.";
$fortunes[] = "Bardzo duo mona zauway, gdy si patrzy.";
$fortunes[] = "Jeli co si wydarza to znaczy, e jest to moliwe. Zatem w walce midzy tob, a wiatem, sta po stronie wiata.";
$fortunes[] = "W poszukiwaniu rozwizania problemu, najbardziej pomocna jest znajomo odpowiedzi.";
$fortunes[] = "Kady przedmiot niezalenie od pooenia, moe w dowolnej chwili zadziaa w zupenie nieoczekiwany sposb z przyczyn, ktre s albo cakowicie niejasne, albo zupenie tajemnicze.";
$fortunes[] = "Wymiary bd zawsze podane w najmniej uytecznych jednostkach.";
$fortunes[] = "Kady przewd przycity na dugo, okae si za krtki.";
$fortunes[] = "Stopie gupoty twojego postpowania, jest wprost proporcjonalny do liczby przygldajcych ci si osb.";
$fortunes[] = "Prawdopodobiestwo wyczerpania si baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$fortunes[] = "Ciar upuszczonej czci jest wprost proporcjonalny do ceny obszaru uderzonego.";
$fortunes[] = "To czego szukasz, znajdziesz w ostatnim spord moliwych miejsc.";
$fortunes[] = "Wniosek to punkt, w ktrym nie masz ju siy dalej myle.";
$fortunes[] = "To co moe si nie uda, nie uda si na pewno.";
$fortunes[] = "Cztery zjawiska blokuj postp ludzkoci - ignorancja, gupota, komitety normalizacyjne, oraz ludzie sprzedajcy komputery.";
$fortunes[] = "Istniej trzy rodzaje kamstw - kamstwa odruchowe, powszechne oraz testy komputerowe.";
$fortunes[] = "Czowiek pracujcy z komputerem, nie postpuje zgodnie z wymaganiami komputera.";
$fortunes[] = "Systemy odporne na idiotw, obsugiwane s wanie przez nich.";
$fortunes[] = "Rozoenie dowolnego urzdzenia na czci jest proste, ponowne jego zoenie, tak eby dziaao, jest niemoliwe.";
$fortunes[] = "Kady skomplikowany monta wymaga trzech rk.";
$fortunes[] = "Kady prosty monta wymaga czterech rk.";
$fortunes[] = "Sprawy pozostawione same sobie, zmieniaj si ze zych na jeszcze gorsze.";
$fortunes[] = "Wszystkie komputery PC s kompatybilne, ale niektre s kompatybilniejsze od innych. Twj jest zawsze mniej kompatybilny.";
$fortunes[] = "Pust dyskietk moesz przeszukiwa dugo i bezskutecznie. Dugo i bezskutecznie moesz przeszukiwa take pen dyskietk. Wniosek - kad dyskietk moesz przeszukiwa dugo i bezskutecznie.";
$fortunes[] = "Komputer suy do tego aby uatwi ci prac, ktrej bez niego w ogle by nie mia.";
$fortunes[] = "Dla komputera nie ma rzeczy niemoliwych z wyjtkiem tych, ktrych od niego wymagamy.";
$fortunes[] = "W wiecie komputerw adna awaria si nie koczy, poniewa przechodzi zawsze w nastpn.";
$fortunes[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitonie zaatakowa.";
$fortunes[] = "W pracy z komputerem, opieranie si na jakichkolwiek zasadach jest bdem.";
$fortunes[] = "Drobne awarie nie isniej, jeeli miaa jednak miejsce drobna awaria, oznacza to, e nie poznae jeszcze jej rzeczywistych rozmiarw.";
$fortunes[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej ci zawiedzie. Kady inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, dziaa bez zakce.";
$fortunes[] = "Masz zawsze o jeden wirus wicej ni sdzisz.";
$fortunes[] = "Program kalkulacyjny, ktry daje waciwy i przyjazny wynik - kamie.";
$fortunes[] = "Wyjtki s liczniejsze od regu. Od wszystkich uznanych wyjtkw istniej wyjtki.";
$fortunes[] = "Klientowi nigdy nie przyjdzie na myl ile kosztuje projekt, tylko ile mona na tym projekcie zaoszczdzi. Jeeli udao ci si wprowadzi w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. aden klient nie wie czego waciwie chce. Kady klient wie dokadnie czego nie chce. aden klient nie chce tego co masz ju gotowe. Nie wie take co chciaby mie zamiast tego. Klient, ktry najmniej paci, marudzi najwicej. Klient da najwikszych zmian dokadnie wtedy, kiedy produkt jest ju gotowy.";
$fortunes[] = "Na polecenie \"napisz tak lub nie\" uytkownik wpisuje \"tak lub nie\". Na polecenie \"wcinij Enter\" uytkownik wpisuje \"Enter\". Na polecenie \"nacinij dowolny klawisz\", uytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programw cakowicie idiotoodpornych.";
$fortunes[] = "W zespole programistw kady ma genialny plan rozwizania problemu. Wszystkie plany si wzajemnie wykluczaj i aden nie prowadzi do poprawnego rozwizania. Liczba osb w zespole programistycznym ma tendencje wzrastajce, niezalenie od iloci pracy.";
$fortunes[] = "01:04 < [hunter]> robi dokumentacje ?
01:04 < [hunter]> :)
01:04 <@Warden> dokumentacj? rb
01:04 <@Warden> ;)
01:04 <@Warden> Baseciq:: jest chtny!
01:04 <@Warden> ;)
01:05 <@Baseciq> zwicie go!!!!!!!!!
01:05 <@Baseciq> szybko!!!
01:05 <@Baseciq> bo ucieknie!!!
01:06 <@agaran> :>
01:08 <@agaran> :>>> Hunterq uwazaj";

$fortunes[] = "19:16.31| <@Baseciq> SELECT users.id, lastname, SUM((type * -2 + 7) * value) FROM users LEFT OUTER JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE status=3 AND deleted=0 GROUP BY users.id;
19:17.00| <@Lexx__> Wy z tymi zapytaniami jobla dostajcie ;P";		     

$fortunes[] = "Lexx (0:16)
GPL nie przewiduje zdaje sie braku odpowiedzialnosci za smierc przez kod ;]";

$fortunes[] = "Subject: [lms] Re: Sieci

Witam.
[hunter napisa:]
> e, to nie Ty miae z arpami co nie tak jako tak ze 3 krzynki i p
> winiacza temu?

Tak, ustawiaem arp 00:00:00:00:00:00 dla adresw broadcastowych i
pada mi wins ;-)
--
ukasz Jarosaw Mozer ;]";

$fortunes[] = "Ilu potrzeba developerw LMSa do wkrcenia arwki?
adnego. Developerzy LMSa zrobi odrazu now lamp.";

$fortunes[] = "Prima Aprilis 2004 - lms@lists.rulez.pl:
<Baseciq>     LMS-Linux 2.0 - dostpny na ftp...
<Woyteck>     Dlaczego ISO ma 33 bajty?
<Detekt>      Poniewa baset wynalaz nowy algorytm optymalizacji.
<T.Chiliski> A ja myl, e to wersja demo, pozbawiona penej funkcjonalnoci.";


mt_srand ((double) microtime()* 100000000);
$layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];

?>
